@@ -1257,14 +1257,14 @@ def inference(
     truncation = None,
     segmentation=None,
     target_range=[1,0],
-    match_intensity=True,
+    poly_order=1,
     verbose=False):
     if segmentation is None:
         pimg = ants.image_clone( image )
         if truncation is not None:
             pimg = ants.iMath( pimg, 'TruncateIntensity', truncation[0], truncation[1] )
         return antspynet.apply_super_resolution_model_to_image(
-            pimg, mdl, target_range=target_range, regression_order=None, verbose=verbose
+            pimg, mdl, target_range=target_range, regression_order=poly_order, verbose=verbose
             )
     else:
         pimg = ants.image_clone( image )
@@ -1291,17 +1291,8 @@ def inference(
                 mdl,
                 segmentation_numbers=mynp,
                 target_range=target_range,
+                poly_order=poly_order,
                 max_lab_plus_one=True  )
-        return antspyt1w.super_resolution_segmentation_per_label(
-            pimg, segmentation, upFactor, mdl,
-            segmentation_numbers=mynp,
-            dilation_amount=8,
-            probability_images=None,
-            probability_labels=None,
-            max_lab_plus_one=True,
-            target_range=target_range,
-            match_intensity=match_intensity,
-            verbose=verbose)
     return None
 
 
@@ -1441,8 +1432,9 @@ def compare_models( model_filenames, img, n_classes=3, identifier=None, verbose=
             tarshape.append( float(upshape[j]) * inspc[j] )
         # uses linear interp
         dimg=ants.resample_image( img, tarshape, use_voxels=False, interp_type=0 )
-        dicesr=0
-        dicenn=0
+        import math
+        dicesr=math.nan
+        dicenn=math.nan
         if verbose:
             print( dimg )
         if upshape[3] == 2:
@@ -1458,6 +1450,10 @@ def compare_models( model_filenames, img, n_classes=3, identifier=None, verbose=
             dimgup=inference( dimg, srmdl, verbose=False  )
         dimglin = ants.resample_image_to_target( dimg, dimgup, interp_type='linear' )
         imgblock = ants.resample_image_to_target( img, dimgup, interp_type='linear'  )
+        dimgup[ imgblock == 0 ]=0
+        dimglin[ imgblock == 0 ]=0
+        dimglinh = ants.histogram_match_image( dimglin, imgblock )
+        dimguph = ants.histogram_match_image( dimgup, imgblock )
         padder = []
         dimwarning=False
         for jj in range(img.dimension):
@@ -1488,10 +1484,10 @@ def compare_models( model_filenames, img, n_classes=3, identifier=None, verbose=
             "imgshape":"x".join(imgshape),
             "mdl": temp,
             "mdlshape":"x".join(a),
-            "PSNR.LIN": antspynet.psnr( imgblock, dimglin ),
-            "PSNR.SR": antspynet.psnr( imgblock, dimgup ),
-            "SSIM.LIN": antspynet.ssim( imgblock, dimglin ),
-            "SSIM.SR": antspynet.ssim( imgblock, dimgup ),
+            "PSNR.LIN": antspynet.psnr( imgblock, dimglinh ),
+            "PSNR.SR": antspynet.psnr( imgblock, dimguph ),
+            "SSIM.LIN": antspynet.ssim( imgblock, dimglinh ),
+            "SSIM.SR": antspynet.ssim( imgblock, dimguph ),
             "DICE.NN": dicenn,
             "DICE.SR": dicesr,
             "dimwarning": dimwarning }
